# Minq

[![PyPI](https://img.shields.io/pypi/v/minq)](https://pypi.org/project/minq)
[![Typecheck](https://github.com/fwcd/minq/actions/workflows/typecheck.yml/badge.svg)](https://github.com/fwcd/minq/actions/workflows/typecheck.yml)

Tiny quantum gate library based on NumPy.
